@@ -6,7 +6,7 @@ test -z "$srcdir" && srcdir=.
 
 PKG_NAME="gnome-voice"
 
-(test -f $srcdir/src/gnome-voice-main.c) || {
+(test -f $srcdir/src/gnome-voice-stream.c) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
     echo " top-level $PKG_NAME directory"
     exit 1
